#python3
#inspired by Dr.Kingshuk Chatterjee
#this package includes PyAvroPhonetic by kaustavdm as installing it via pip does not work properly
#Also requires pyenchant
globstr=""
def conv(stre="",delim="!?.",n=0):
    '''convert bengali text written in english to bengali while keeping english ony text '''
    import string#importing string
    from pyavrophonetic import avro
    import enchant
    d = enchant.DictWithPWL("en_GB","data/bdict4.txt")
    strret=""
    english=0
    bengali=0
    startendsign=""
    global globstr
    try:
        while stre[n]!="." and stre[n]!="?" and stre[n]!="!":
            # Iterating from the back of the sentence
            strret+=stre[n]
            n += 1
        else:
          endendsign=stre[n]  
    except:
        return "Done"
    strlst=strret.split()
    lenghty=len(strlst)
    for element in range(lenghty):
        flag1=0
        flag2=0
        if d.check(strlst[element]):
            flag1+=1
        elementben=avro.parse(strlst[element])
        if d.check(elementben):
            flag2+=1
        if flag1==1 and flag2==0:
            english+=1
        elif flag1==0 and flag2==1:
            bengali+=1
        elif flag1==1 and flag2==1:
            english+=1
            bengali+=1
        else:
            pass
    if english>bengali:
        pass
        strret=" ".join(strlst)
    elif bengali>english:
        for element in range(lenghty):
            flag1=0
            flag2=0
            if d.check(strlst[element]):
                flag1+=1
            elementben=avro.parse(strlst[element])
            if d.check(elementben):
                flag2+=1
            if flag1==1 and flag2==0:
                pass
            elif flag1==0 and flag2==1:
                strlst[element]=elementben
            elif flag1==1 and flag2==1:
                pass
            else:
                pass
            
        strret= " ".join(strlst)
    else:
        pass
    strret=startendsign+strret+avro.parse(endendsign)
    print (strret,)
    globstr+=strret
    conv(stre,n=n+1)
    
def call(str1):
    '''Function to send converted text to file converter'''
    global globstr
    globstr=""
    conv(str1)
    return globstr

#Usage: conv("Folder zip korte hobe abar . ami korbo.")

def callfileconvert():
    '''Driver function for converting files'''
    while True:
        flname=input("Enter txt file name:")
        with io.open(flname,'r',encoding='utf8') as opf:
                   text11 = opf.read()
        rettxt=call(str1=text11)
        with io.open(flname+"-converted.txt",'w',encoding='utf8') as opf:
                   opf.write(rettxt)
        print("Done converting an saved in file:",flname,"-coverted.txt")
        choi=input("Enter choice(1-Continue/0-Abort):")
        if choi=="0":
            print("Closing....")
            break
        else:
            pass
    
conv("Folder zip korte hobe abar . ami korbo.")



#!/usr/bin/env python

"""Provides validation functions for pyAvroPhonetic

-------------------------------------------------------------------------------

Copyright (C) 2013 Kaustav Das Modak <kaustav.dasmodak@yahoo.co.in.

This file is part of pyAvroPhonetic.

pyAvroPhonetic is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

pyAvroPhonetic is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with pyAvroPhonetic.  If not, see <http://www.gnu.org/licenses/>.

"""


# Imports
from pyavrophonetic import config


def is_vowel(text):
    """Check if given string is a vowel"""
    return text.lower() in config.AVRO_VOWELS

def is_consonant(text):
    """Check if given string is a consonant"""
    return text.lower() in config.AVRO_CONSONANTS

def is_number(text):
    """Check if given string is a number"""
    return text.lower() in config.AVRO_NUMBERS

def is_punctuation(text):
    """Check if given string is a punctuation"""
    return not (text.lower() in config.AVRO_VOWELS or
                text.lower() in config.AVRO_CONSONANTS)

def is_case_sensitive(text):
    """Check if given string is case sensitive"""
    return text.lower() in config.AVRO_CASESENSITIVES

def is_exact(needle, haystack, start, end, matchnot):
    """Check exact occurrence of needle in haystack"""
    return ((start >= 0 and end < len(haystack) and
             haystack[start:end] == needle) ^ matchnot)

def fix_string_case(text):
    """Converts case-insensitive characters to lower case

    Case-sensitive characters as defined in config.AVRO_CASESENSITIVES
    retain their case, but others are converted to their lowercase
    equivalents. The result is a string with phonetic-compatible case
    which will the parser will understand without confusion.
    """
    fixed = []
    for i in text:
        if is_case_sensitive(i):
            fixed.append(i)
        else:
            fixed.append(i.lower())
    return ''.join(fixed)



#!/usr/bin/env python

try:
    from setuptools import setup

    setup(name='phonetic2bengali',
          version='1.0.1',
          description='convert bengali text written in english to bengali while keeping english ony text',
          long_description=open('README.rst', 'rt').read(),
          author='Subrata Sarkar',
          author_email='subrotosarkar32@gmail.com',
          url='https://github.org/SubrataSarkar32/phonetic2bengali/',
          packages=['phonetic2bengali','phonetic2bengali.pyavrophonetic','phonetic2bengali.pyavrophonetic.utils'],
          package_data = {'': ['*.txt', '*.json','*.rst']},
          include_package_data = True,
          install_requires=["simplejson >= 3.0.0","pyenchant >= 2.0.0"],
          license='Apache v2.0',
          classifiers=[
            'Development Status :: 3 - Alpha',
            'Intended Audience :: Developers',
            'License :: OSI Approved :: Apache Software License',
            'Operating System :: OS Independent',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3.6',
            ]
          )

except ImportError:
    print('Install setuptools')
